provider "aws" {
  region     = var.region
  access_key = var.cli_usr
  secret_key = var.cli_usr_key
}

# creating local variables
locals {
  environment = "development"
  cidr_block  = "0.0.0.0/0"
}

# security group resource
resource "aws_security_group" "ec2-sg" {
  vpc_id = var.vpcid
  ingress = [
    {
      description      = "ssh"
      from_port        = 22
      to_port          = 22
      protocol         = "tcp"
      cidr_blocks      = ["${local.cidr_block}"]
      ipv6_cidr_blocks = null
      prefix_list_ids  = null
      security_groups  = null
      self             = null
    }
  ]
  egress = [
    {
      description      = "all-open"
      from_port        = 0
      to_port          = 0
      protocol         = "-1"
      cidr_blocks      = ["${local.cidr_block}"]
      ipv6_cidr_blocks = null
      prefix_list_ids  = null
      security_groups  = null
      self             = null
    }
  ]
  tags = {
    "label" = "${local.environment}"
  }
}

# ec2 resource
resource "aws_instance" "ec2_example" {
  ami               = var.ami_id
  availability_zone = var.zone_id
  instance_type     = var.instance_type
  key_name          = var.key_pair
  count             = var.instance_count
  security_groups   = ["${aws_security_group.ec2-sg.id}"]
  subnet_id         = var.subnet_id
  ebs_block_device {
    device_name           = var.ebs_volume_name
    volume_size           = var.ebs_volume_size
    volume_type           = var.ebs_volume_type
    delete_on_termination = true
  }
  tags = {
    "label" = "${local.environment}"
  }
}
